/*
 * Java application using Oracle "thin" driver
 * Oracle Net/Net8/SQL*Net not required on client
 *
 * @version 1.01 01/24/2002
 * @author  John Jay King
 */

import java.sql.*;	// needed for JDBC
import java.io.*;
import java.awt.*;

/** Sample use of Oracle "thin" JDBC connection
 *  <br>
 *  Program uses JDBC batch update to load a database
 *  table using input file data
 */
public class OraBatchFile
{
  public static void main (String args [])
  {
	Connection conn = null;
	Statement stmt = null;
	ResultSet rset = null;
	String connectStr = "jdbc:oracle:thin:@tecra82:1521:tecra82";
	String userid =  "scott"; // do not hard code in real program!
	String passwd =  "tiger"; // do not hard code in real program!

	BufferedReader myFile;
	FileDialog	myFileDialog;

	String      fileRecord 	= null;
	String		fileEmpno 	= null;
	String		fileEmpName = null;
	String		fileEmpJob 	= null;
	String		fileEmpMgr 	= null;
	String		fileEmpSal 	= null;
	String		fileEmpComm = null;
	String		fileEmpDept = null;
	String		fileEmpHire = null;
	String		datefmt 		= "mm/dd/rr";
	String		insertStr   = null;
	int			outEmpno 	= 0;
	int			outEmpmgr 	= 0;
	double		outSal 		= 0.0;
	double		outComm 		= 0.0;
	short			nullSal 		= 0;
	short			nullComm 	= 0;
	short			nullEmpmgr	= 0;
	int			outDeptno	= 0;;
	try {
		// Load the Oracle JDBC driver
		DriverManager.registerDriver(new oracle.jdbc.driver.OracleDriver());

		// Connect to the database, connection string format:
		// 	jdbc:oracle:thin:@**hostcomputer**:**port**:**oraclesid**
		conn =
	      DriverManager.getConnection (connectStr,userid,passwd);
		System.out.println("Successfully connected to oracle");
	}
	catch (SQLException e) {
		System.out.println("Problem connecting to Oracle");
		e.printStackTrace();
		return;
	}

	myFileDialog = new FileDialog(new Frame(),"Get Person File",
										FileDialog.LOAD);
	myFileDialog.setDirectory("\\JavaSamples");
	myFileDialog.show(); //
	try {
		myFile = new BufferedReader(
		new FileReader(myFileDialog.getDirectory()
						  +myFileDialog.getFile()));
	}
	catch (IOException e) {
		System.out.println("\n\nError opening file!\n\n");
		e.printStackTrace();
		return;
	}


	try {
		// Create a Statement
		stmt = conn.createStatement ();
		conn.setAutoCommit(false);

		try { // try process records
			while (myFile.ready()) {
				fileRecord = myFile.readLine();// read record into string
				if (fileRecord == null) {
					continue;
				}
				else {
					fileEmpno 	= fileRecord.substring(0,4);
					fileEmpName = fileRecord.substring(5,15);
					fileEmpJob  = fileRecord.substring(16,25);
					fileEmpMgr 	= fileRecord.substring(26,30);
					fileEmpSal 	= fileRecord.substring(31,39);
					fileEmpComm = fileRecord.substring(40,48);
					fileEmpDept	= fileRecord.substring(49,51);
					fileEmpHire	= fileRecord.substring(52,60);
					try {
						outSal = Double.parseDouble(fileEmpSal);
						nullSal = 0;
					}
					catch (NumberFormatException e) {
						fileEmpSal = "null";
						outSal = 0;
						nullSal = -1;
					}
					try {
						outComm = Double.parseDouble(fileEmpComm);
						nullComm = 0;
					}
					catch (NumberFormatException e) {
						fileEmpComm = "null";
						outComm = 0;
						nullComm = -1;
					}
					try {
						outEmpmgr = Integer.parseInt(fileEmpMgr);
						nullEmpmgr = 0;
					}
					catch (NumberFormatException e) {
						fileEmpMgr = "null";
						outEmpmgr = 0;
						nullEmpmgr = -1;
					}
					insertStr = "INSERT INTO EMP "
										+ " (EMPNO,ENAME,JOB,MGR,SAL,COMM,HIREDATE,DEPTNO) "
										+ " VALUES (" + fileEmpno + ","
										+ "'" + fileEmpName + "'" + ","
										+ "'" + fileEmpJob + "'" + ","
										+ fileEmpMgr + ","
										+ fileEmpSal + ","
										+ fileEmpComm + ","
										+ "to_date(" + "'" + fileEmpHire + "','" + datefmt + "')" + ","
										+ fileEmpDept + ")";
					stmt.addBatch(insertStr);
				} // end else
			} // end while loop
			int [] updateCounts = stmt.executeBatch();
			for (int i = 0; i < updateCounts.length; i++) {
				System.out.println("Insert " + i + " MODIFIED " + updateCounts[i] + " rows");
			}
		} // end try
		catch (IOException e) {
			System.out.println("Problem processing input record");
			throw e;
		}
		catch (SQLException e) {
			System.out.println("Problem with batch updates");
			throw e;
		}
		try {
			// Select the ENAME and JOB columns from the EMP table
		    rset = stmt.executeQuery ("select ename,job from emp");
		}
		catch (SQLException e) {
			System.out.println("Problem building result set");
			throw e;
		}


		try {
		    // Loop through results set and print the employee info
		    while (rset.next ())
	      		System.out.println ("Employee: " + rset.getString (1)
	                        + " is a " + rset.getString(2));
	        conn.rollback(); // conn.commit();
		}
		catch (SQLException e) {
			System.out.println("Problem processing row");
			e.printStackTrace();
			throw e;
		}
	}
	catch (SQLException e) {
		System.out.println("Problem with SQL statement execution");
		e.printStackTrace();
		try {
			conn.rollback();
		}
		catch (SQLException e2) {
			System.out.println("Trouble rolling back errors!");
		}
	}
	catch (IOException e) {
		System.out.println("Problem processing input record or file");
		e.printStackTrace();
	}
	finally {
		try {
			   // Close statement
			 stmt.close();
			 // Close connection
			 conn.close();
		 }
		 catch (SQLException e) {
			 System.out.println("Problem closing statement or connection");
			 e.printStackTrace();
		 }
	 }
  } // end main
} // end OraTest