/*
 * Java application using Oracle "thin" driver
 * Oracle Net/Net8/SQL*Net not required on client
 *
 * @version 1.01 04/01/2000
 * @author  John Jay King
 */

import java.sql.*;	// needed for JDBC

/** Sample use of Oracle "thin" JDBC connection */
public class OraTest
{
  public static void main (String args [])
  {
	  Connection conn = null;
	  Statement stmt = null;
	  ResultSet rset = null;
	  try {
	    // Load the Oracle JDBC driver
	    DriverManager.registerDriver(new oracle.jdbc.driver.OracleDriver());

	    // Connect to the database, connection string format:
	    // 	jdbc:oracle:thin:@**hostcomputer**:**port**:**oraclesid**
	    conn =
	      DriverManager.getConnection ("jdbc:oracle:thin:@tecra82:1521:tecra82","scott", "tiger");
		System.out.println("Successfully connected to oracle");
	}
	catch (SQLException e) {
		System.out.println("Problem connecting to Oracle");
		e.printStackTrace();
		return;
	}

	try {
	    // Create a Statement
	    stmt = conn.createStatement ();

		try {
			// Select the ENAME and JOB columns from the EMP table
		    rset = stmt.executeQuery ("select ename,job from emp");
		}
		catch (SQLException e) {
			System.out.println("Problem building result set");
			e.printStackTrace();
			throw e;
		}


		try {
		    // Loop through results set and print the employee info
		    while (rset.next ())
	      		System.out.println ("Employee: " + rset.getString (1)
	                        + " is a " + rset.getString(2));
		}
		catch (SQLException e) {
			System.out.println("Problem processing row");
			e.printStackTrace();
			throw e;
		}
	}
	catch (SQLException e) {
		System.out.println("Problem with SQL statement execution");
		e.printStackTrace();
	}
	finally {
		try {
			   // Close statement
			 stmt.close();
			 // Close connection
			 conn.close();
		 }
		 catch (SQLException e) {
			 System.out.println("Problem closing statement or connection");
			 e.printStackTrace();
		 }
	 }
  } // end main
} // end OraTest